Changelog
=========


2.0.0 (2018-04-27)
------------------

- Breaking: rename the results attributes to be 'items'
  [erral]

- Breaking: remove 'language' attribute from top-level response
  [erral]

- Make `@translations` endpoint expandable
  [erral]


1.0.0 (2018-01-18)
------------------

- Fixed test setup
  [erral]

- Fix classifiers
  [erral]


1.0b1 (2017-11-05)
------------------

- Initial release.
  [erral]
